package com.ruoyi.app.service.impl;

import java.util.List;

import com.ruoyi.app.domain.AppStand;
import com.ruoyi.app.mapper.AppStandMapper;
import com.ruoyi.app.service.IAppStandService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-14
 */
@Service
public class AppStandServiceImpl implements IAppStandService
{
    @Autowired
    private AppStandMapper appStandMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param standId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public AppStand selectAppStandByStandId(String standId)
    {
        return appStandMapper.selectAppStandByStandId(standId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appStand 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<AppStand> selectAppStandList(AppStand appStand)
    {
        return appStandMapper.selectAppStandList(appStand);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param appStand 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertAppStand(AppStand appStand)
    {
        return appStandMapper.insertAppStand(appStand);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param appStand 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateAppStand(AppStand appStand)
    {
        return appStandMapper.updateAppStand(appStand);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param standIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppStandByStandIds(String[] standIds)
    {
        return appStandMapper.deleteAppStandByStandIds(standIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param standId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppStandByStandId(String standId)
    {
        return appStandMapper.deleteAppStandByStandId(standId);
    }
}
